# Minimalist RESTful Automation (mra) framework

This is a simple framework for automating REST operations. It uses a fusion of script-based and python-based approaches
allow *less* technical users to use actions in a generic way to create new tasks. It also allows easy extension by third
parties.

# Status

Somewhat working. Published to pypi under mra.